*******************************************************************************************************************************
*                         COMMANDS (AND DATA REFERENCES) NEEDED TO REPLICATE
*
*									Creating Parties in Congress:
*								  The Emergence of a Social Network
*									   By Keith L. Dougherty
*									    <dougherk@uga.edu>
*
*									      PUBLISHED IN
*							      Political Research Quarterly
*******************************************************************************************************************************

* NOTES:
* Adams (leader1), Hamilton (leader2), Jefferson (leader3), and Madison (leader4)
* drop4 removes three leaders from rhs of regressions (not madison becuase he is in Congress) as well as people who were never in Congress:
*	icpsr_id == 2819 | icpsr_id == 4469 | icpsr_id == 4748 | icpsr_id == 5668 | icpsr_id == 6422 | icpsr_id == 6963 | icpsr_id == 9048 | icpsr_id == 9239 | icpsr_id == 9271 | icpsr_id == 10407
* To limit the analysis to those who are either in congress or one year before entering congress, include the qualifers left_cong!=1 & pre_cong !=1
*   Note; if somone is two or more years before entering the federal Congress for the first time, pre_cong !=1 will exclude them.  However, anyone one year prior 
*   to entering the federal Congress for the first time will not be excluded by pre_cong !=1 & left_cong!=1.  Anyone who left Congress then latter 
*   returned, are excluded with these two qualifiers.


* TABLE 2. The Probability of an Asymmetric Tie and Qualities of the Legislator
* set the following path to your directory
use "C:\Users\dougherk\Dropbox\parties_and_networks\data\correspondence_tables\basic_tables\parties_networks_long.dta", clear
tsset dyad year, yearly
* Column (1)
logit d_lc L.d_lc d_cl dist_apsa_nom sov_wnom state_same state_leg_yrs age age2 house senate exec volume leader2 leader3 leader4 if apsa_unom1 !=. & drop4==0, vce(cluster lead) 
* Column (2)
logit d_lc L.d_lc d_cl dist_apsa_nom sov_wnom state_same state_leg_yrs age age2 house senate exec volume leader2 leader3 leader4 if apsa_unom1 !=. & drop4==0 & left_cong!=1 & pre_cong !=1, vce(cluster lead) 
* Column (3)
gen ld_lc = L.d_lc
logit d_lc i.ld_lc i.d_cl c.dist_apsa_nom##leader2 c.dist_apsa_nom##i.leader3 c.dist_apsa_nom##i.leader4 c.sov_wnom i.state_same c.state_leg_yrs c.age c.age2 i.house i.senate i.exec c.volume if apsa_unom1 !=. & drop4==0, vce(cluster lead) 


* FIGURE 4. Predicted Letter Sent and the Ideological Distance of the Legislator
* set the following path to your directory
use "C:\Users\dougherk\Dropbox\parties_and_networks\data\correspondence_tables\basic_tables\parties_networks_long.dta", clear
tsset dyad year, yearly
gen ld_lc = L.d_lc
logit d_lc i.ld_lc i.d_cl c.dist_apsa_nom##leader2 c.dist_apsa_nom##i.leader3 c.dist_apsa_nom##i.leader4 c.sov_wnom i.state_same c.state_leg_yrs c.age c.age2 i.house i.senate i.exec c.volume if apsa_unom1 !=. & drop4==0, vce(cluster lead) 
*	Hamilton
    margins leader2, at((mean) _all d_cl=0 ld_lc=0 state_same=0 house=0 senate=0 exec=0 leader3=0 leader4=0 dist_apsa_nom=(0(.1)2) ) vsquish noatlegend post 
    marginsplot, plot1opts(lcolor(edkblue) mcolor(edkblue)) ci1opts(lcolor(edkblue)) plot2opts(lcolor(cranberry) mcolor(cranberry)) ci2opts(lcolor(cranberry)) ytitle(Probability of Sending a Letter) xtitle(Distance) title(Comparing Adams vs Hamilton) xlabel(0(.1)2) legend(order(4 "Hamilton" 3 "Adams") symxsize(*.8)) scheme(s1color)
*   Jefferson
    margins leader3, at((mean) _all d_cl=0 ld_lc=0 state_same=0 house=0 senate=0 exec=0 leader2=0 leader4=0 dist_apsa_nom=(0(.1)2) ) vsquish noatlegend post 
    marginsplot, plot1opts(lcolor(edkblue) mcolor(edkblue)) ci1opts(lcolor(edkblue)) plot2opts(lcolor(cranberry) mcolor(cranberry)) ci2opts(lcolor(cranberry)) ytitle(Probability of Sending a Letter) xtitle(Distance) title(Comparing Adams vs Jefferson) xlabel(0(.1)2) legend(order(4 "Jefferson" 3 "Adams") symxsize(*.8)) scheme(s1color)
*   Madison
    margins leader4, at((mean) _all d_cl=0 ld_lc=0 state_same=0 house=0 senate=0 exec=0 leader2=0 leader3=0 dist_apsa_nom=(0(.1)2) ) vsquish noatlegend post 
    marginsplot, plot1opts(lcolor(edkblue) mcolor(edkblue)) ci1opts(lcolor(edkblue)) plot2opts(lcolor(cranberry) mcolor(cranberry)) ci2opts(lcolor(cranberry)) ytitle(Probability of Sending a Letter) xtitle(Distance) title(Comparing Adams vs Madison) xlabel(0(.1)2) legend(order(4 "Madison" 3 "Adams") symxsize(*.8)) scheme(s1color)


* TABLE 3. The Probability of Becoming a Federalist (1795-1802)
* set the following path to your directory
use "C:\Users\dougherk\Dropbox\parties_and_networks\final_word_version\public_data\party_regression.dta", clear
logit fparty df dr college lawyer state_leg_yrs_1795 age1795 age2 new_england mid_atlantic fce4 fce5 fce6 if (fce1==0 & fce2==0 & fce3==0), robust


* TABLE 4. Weighted Ties and the Qualities of a Legislator
* set the following path to your directory
use "C:\Users\dougherk\Dropbox\parties_and_networks\data\correspondence_tables\basic_tables\parties_networks_long.dta", clear
tsset dyad year, yearly
* COLUMN (1). 
  * CREATE A WEIGHTED TIE FROM THE LEADER TO A CORRESPONDENT (more weight, stronger political tie)
  * weigthed as 1 if the sender contacted the receiver that year.
    gen x_lc = d_lc
  * add 1 to the weight if sender contacted receiver more than five times that year and a majority of those ties were mostly political
  replace x_lc = x_lc + 1 if (w_lc > 5) & (nmp_lc > .5 * w_lc)
  * add another 1 to the weight if sender wrote about parties in most of his letters to the receiver that year.
  replace x_lc = x_lc + 1 if (ndp_lc > .5 * w_lc)
  * CREATE A WEIGHTED TIE FROM THE CORRESPONDENT TO A LEADER (more weight, stronger political tie)
  * weigthed as 1 if the sender contacted the receiver that year.
  gen x_cl = d_cl
  * add 1 to the weight if sender contacted receiver more than five times that year and a majority of those ties were mostly political
  replace x_cl = x_cl + 1 if (w_cl > 5) & (nmp_cl > .5 * w_cl)
  * add another 1 to the weight if sender wrote about parties in most of his letters to the receiver that year.
  replace x_cl = x_cl + 1 if (ndp_cl > .5 * w_cl)
  * REGRESS
  ologit x_lc x_cl L.x_lc state_same house senate exec volume dist_apsa_nom sov_wnom state_leg_yrs age age2 leader2 leader3 leader4 if apsa_unom1 !=. & drop4==0, vce(cluster lead) 
* COLUMN (2). 
  * CREATE A WEIGHTED TIE FROM THE LEADER TO A CORRESPONDENT (more weight, stronger political tie)
  * weigthed as 1 if the sender contacted the receiver that year.
  gen xx_lc = d_lc
  * add 1 to the weight if sender contacted receiver more than once that year and a majority of those ties were mostly political
  replace xx_lc = xx_lc + 1 if (w_lc > 1) & (nmp_lc > .5 * w_lc)
  * add another 1 to the weight if sender wrote about parties in most of his letters to the receiver that year.
  replace xx_lc = xx_lc + 1 if (ndp_lc > .5 * w_lc)
  * CREATE A WEIGHTED TIE FROM THE CORRESPONDENT TO A LEADER (more weight, stronger political tie)
  * weigthed as 1 if the sender contacted the receiver that year.
  gen xx_cl = d_cl
  * add 1 to the weight if sender contacted receiver more than once that year and a majority of those ties were mostly political
  replace xx_cl = xx_cl + 1 if (w_cl > 1) & (nmp_cl > .5 * w_cl)
  * add another 1 to the weight if sender wrote about parties in most of his letters to the receiver that year.
  replace xx_cl = xx_cl + 1 if (ndp_cl > .5 * w_cl)
 * REGRESS
  ologit xx_lc xx_cl L.xx_lc state_same house senate exec volume dist_apsa_nom sov_wnom state_leg_yrs age age2 leader2 leader3 leader4 if apsa_unom1 !=. & drop4==0, vce(cluster lead) 
* COLUMN (3). 
  * CREATE A WEIGHTED TIE FROM THE LEADER TO A CORRESPONDENT (more weight, stronger political tie)
  * weigthed as 1 if the sender contacted the receiver that year.
  gen xxx_lc = d_lc
  * add 1 to the weight if sender contacted receiver more than once that year and a majority of those ties were mostly political
  replace xxx_lc = xxx_lc + 1 if (w_lc > 1) & (nmp_lc > .5 * w_lc)
  * add another 1 to the weight if sender wrote about parties in at least one letter that year.
  replace xxx_lc = xxx_lc + 1 if (ndp_lc > 0)
  * CREATE A WEIGHTED TIE FROM THE CORRESPONDENT TO A LEADER (more weight, stronger political tie)
  * weigthed as 1 if the sender contacted the receiver that year.
  gen xxx_cl = d_cl
  * add 1 to the weight if sender contacted receiver more than once that year and a majority of those ties were mostly political
  replace xxx_cl = xxx_cl + 1 if (w_cl > 1) & (nmp_cl > .5 * w_cl)
  * add another 1 to the weight if sender wrote about parties in at least one letter that year.
  replace xxx_cl = xxx_cl + 1 if (ndp_cl > 0)
 * REGRESS
  ologit xxx_lc xxx_cl L.xxx_lc state_same house senate exec volume dist_apsa_nom sov_wnom state_leg_yrs age age2 leader2 leader3 leader4 if apsa_unom1 !=. & drop4==0, vce(cluster lead) 





NEXT: 
1- CUT DOWN THE DATA TO WHAT IS USED IN THE TABLES ABOVE AND SAVE IN <C:\Users\dougherk\Dropbox\parties_and_networks\final_word_version\public_data\>
   NOTE: THE TABLE 3 DATA ARE IN A DIFFERENT DIRECTORY BECAUSE YOU HAVE TO CUT DOWN VARIABLES THAT ARE IN THERE: fce1 to fce6.
	
   LONG VARIABLES TO KEEP
    keep dyad year leader1 leader2 leader3 leader4 name corr_id icpsr_id state state_num party birth_mth birth_day birth_year d_lc d_lc d_cl dist_apsa_nom sov_wnom state_same state_leg_yrs age age2 house senate exec volume lead apsa_unom1 apsa_unom2 drop4 left_cong pre_cong w_lc w_cl ndp_lc ndp_cl nmp_lc nmp_cl
	
   PARTY REG VARIABLES TO KEEP
   keep corr_id icpsr_id name state state_num birth_mth birth_day birth_year fparty df dr college lawyer state_leg_yrs_1795 age1795 age2 new_england mid_atlantic fce1 fce2 fce3 fce4 fce5 fce6 fce7
     
2- MAKE A CODEBOOK (if it's not easy, skip it).
3- MOVE PUBLIC DATA TO A DATA DIRECTORY
